@@ -1,17 +1,17 @@
 function Base.Array(a::StridedView)
     b = Array{eltype(a)}(undef, size(a))
-    copyto!(StridedView(b), a)
+    copy!(StridedView(b), a)
     return b
 end
 
 function (Base.Array{T})(a::StridedView{S,N}) where {T,S,N}
     b = Array{T}(undef, size(a))
-    copyto!(StridedView(b), a)
+    copy!(StridedView(b), a)
     return b
 end
 
 function (Base.Array{T,N})(a::StridedView{S,N}) where {T,S,N}
     b = Array{T}(undef, size(a))
-    copyto!(StridedView(b), a)
+    copy!(StridedView(b), a)
     return b
 end
